@@ -10,28 +10,28 @@ class action(object):
         self.name = name
         self.hotkey = hotkey
         self.kwargs = kwargs
-        
+
     def __str__(self):
         return "{}: {}".format(self.hotkey, self.name)
-        
-        
+
+
 class moveNorth(action):
     def __init__(self):
         super(moveNorth,self).__init__(method=Player.move_north, name="Move north", hotkey = "n")
-        
+
 class moveSouth(action):
     def __init__(self):
         super(moveSouth,self).__init__(method=Player.move_south, name="Move south", hotkey = "s")
-        
+
 class moveEast(action):
     def __init__(self):
         super(moveEast,self).__init__(method=Player.move_east, name="Move east", hotkey = "e")
-        
+
 class moveWest(action):
     def __init__(self):
         super(moveWest,self).__init__(method=Player.move_west, name="Move west", hotkey = "w")
-        
-        
+
+
 class viewInventory(action):
     #Prints the players inventory
     def __init__(self):
@@ -50,22 +50,22 @@ class viewStats(action):
 
 class attack(action):
     def __init__(self, enemy):
-        super(attack,self).__init__(method=Player.attack, name = "Attack", hotkey = "a", enemy = enemy)
+        super(attack,self).__init__(method=Player.attack, name = "Attack!", hotkey = "a", enemy = enemy)
+
 
-        
 class flee(action):
     def __init__(self, tile):
-        super(flee,self).__init__(method=Player.flee, name = "Flee!", hotkey = "f", tile = tile)
-        
+        super(flee,self).__init__(method=Player.flee, name = "Flee", hotkey = "f", tile = tile)
+
 
         """New functionality"""
-        
+
 class sharpenStick(action):
     #Makes the player sharpen a stick and add the sharpenedStick weapon to the inventory
     def __init__(self):
         super(sharpenStick,self).__init__(method=Player.sharpen, name = "Sharpen the wooden stick", hotkey = "g")
 
-        
+
 class killSelf(action):
     def __init__(self):
         super(killSelf,self).__init__(method=Player.killSelfie, name = "This is no fun 😞", hotkey = "m")
@@ -92,4 +92,4 @@ class giveTenG(action):
 
 class sellMushroom(action):
     def __init__(self):
-        super(sellMushroom, self).__init__(method=Player.sellAmushroom, name="Sell mushroom", hotkey = "g")
\ No newline at end of file
+        super(sellMushroom, self).__init__(method=Player.sellAmushroom, name="Sell mushroom", hotkey = "g")
