@@ -10,7 +10,7 @@ import random
 
 class Player(object):
     def __init__(self):
-        self.inventory = [items.gold(5), items.fists()]
+        self.inventory = [items.gold(10), items.fists()]
         self.hp = 20
         self.strength= 2
         self.location_x, \
@@ -19,12 +19,11 @@ class Player(object):
 
 
 
-    def has_stick(self):
-            if items.sharpenedStick in self.inventory:
-                return True
-                # print("got that stick already")
-            else:
-                return False
+    def has_wstick(self):
+            for item in self.inventory:
+                if item.name is "Wooden stick":
+                    return True
+
 
     def is_alive(self):
         return self.hp > 0
