@@ -71,7 +71,7 @@ class startingRoom(mapTile):
     @run_once
 
     def tile_text(self):
-        return "\n" "\n" """Suddenly you wake up and find yourself in a dark forest... You look around, wondering how you got there. 
+        return "\n" "\n" """Suddenly you wake up and find yourself in a dark forest... You look around, wondering how you got there.
 It's damp and cold, so you decide to get moving. """
 
     def modify_player(self, player):
@@ -163,6 +163,7 @@ class enemyRoom(mapTile):
         self.enemy = enemy
         self.hasAttacked = False
         self.metEnemy = False
+        self.timesVisited=0
         super(enemyRoom, self).__init__(x, y)
 
     def modify_player(self, player):
@@ -206,7 +207,6 @@ class enemyRoom(mapTile):
 
 class bigSpiderTile(enemyRoom):
     def __init__(self, x,y):
-        #self.hasAttacked = False
         super(bigSpiderTile, self).__init__(x,y, enemies.bigSpider())
 
     def tile_text(self):
@@ -244,6 +244,7 @@ class banditTile(enemyRoom):
     def tile_text(self):
         if (self.enemy.is_alive() and self.enemy.isaggressive == True):
             self.metEnemy = True
+            self.timesVisited += 1
             return """The gives out a roar and strikes you, 'RRAAAAAHH!!'
             """
 
@@ -253,7 +254,7 @@ class banditTile(enemyRoom):
             """)
 
         elif (self.metEnemy == True) and (self.enemy.is_alive()) and (self.enemy.isaggressive == False):
-            return """The bandit just stands and looks at you with an evil grin on his face"""
+            return """The bandit stands and looks at you with an evil grin on his face, will you pay up, fight or flee?"""
 
         else:
             return """The corpse of a dead man lies on the ground.
@@ -332,14 +333,13 @@ class findStickTile(lootRoom):
     def __init__(self, x, y):
         super(findStickTile, self).__init__(x, y, items.stick())
 
+
     def add_loot(self, player):
         for i in range(0, len(player.inventory)):
-            print(player.inventory[i])
+            # print(player.inventory[i])
             if player.inventory[i].name == "Wooden stick":
-                print("Hi!")
-                pass
+                print("Stick is here")
             else:
-                print("Its not there")
                 player.inventory.append(self.item)
                 break
 
@@ -361,8 +361,3 @@ class findMushRoomTile(lootRoom):
             return """Your notice something on the ground. It's a strange looking mushroom! You pick it up."""
         else:
             return """Another unremarkable part of the forrest. Better keep moving."""
-
-
-
-
-
